@@ -41,7 +41,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -59,7 +59,6 @@ use Dist::Zilla::Plugin::CheckChangesHasContent             ();
 use Dist::Zilla::Plugin::CheckExtraTests                    ();
 use Dist::Zilla::Plugin::CheckPrereqsIndexed                ();
 use Dist::Zilla::Plugin::ConfirmRelease                     ();
-use Dist::Zilla::Plugin::FakeRelease                        ();
 use Dist::Zilla::Plugin::GatherFromManifest                 ();
 use Dist::Zilla::Plugin::Hook                       0.007   ();   # We need Hook::Releaser.
 use Dist::Zilla::Plugin::Manifest::Write                    ();
@@ -113,25 +112,24 @@ has minimum_perl => (
     },
 );
 
-#pod =option fake_release
+#pod =option local_release
 #pod
-#pod If true (C<1>), release will be a fake one, i. e. no external operations will be done:
-#pod C<UploadToCPAN> plugin will be replaced with C<FakeRelease> (which does nothing), and C<hg push>
-#pod will not be performed.
+#pod If true, release will be a local one, i. e. no external operations will be done: C<UploadToCPAN>
+#pod and C<hg push> will be skipped, <hg tag> will create a local tag.
 #pod
-#pod Option can be set trough F<dist.ini> file or with C<FAKE_RELEASE> environment variable.
+#pod Option can be set trough F<dist.ini> file or with C<DZIL_LOCAL_RELEASE> environment variable.
 #pod
 #pod C<Bool>, optional, default value is 0.
 #pod
 #pod =cut
 
-has fake_release => (
+has local_release => (
     is          => 'ro',
     isa         => 'Bool',
     lazy        => 1,
     default     => sub {
         my ( $self ) = @_;
-        return $self->payload->{ fake_release } // $ENV{ FAKE_RELEASE };
+        return $self->payload->{ local_release } // $ENV{ DZIL_LOCAL_RELEASE };
     },
 );
 
@@ -285,6 +283,13 @@ sub configure {
 
         [ 'OurPkgVersion' ],
 
+        [ 'Templates' => {
+            'templates' => [
+                '@Author::VDB/source doc',
+                @{ $self->templates },
+            ],
+        } ],
+
         [ 'SurgicalPodWeaver' => {
             'config_plugin' => '@Author::VDB',
             'replacer'      => 'replace_with_comment',
@@ -298,13 +303,6 @@ sub configure {
             ],
         } ],
 
-        [ 'Templates' => {
-            'templates' => [
-                '@Author::VDB/source doc',
-                @{ $self->templates },
-            ],
-        } ],
-
         #
         #   Update sources
         #
@@ -322,7 +320,7 @@ sub configure {
                     my $new_bulk = $new_file->slurp;
                     my $old_bulk = $old_file->exists ? $old_file->slurp : undef;
                     if ( not defined( $old_bulk ) or $new_bulk ne $old_bulk ) {
-                        $self->log( [ 'Updating %s...', $file->name ] );
+                        $self->log( [ 'updating %s', $file->name ] );
                         $old_file->spew( $new_bulk );
                     };
                 };
@@ -505,12 +503,12 @@ sub configure {
                     my $root = path( $self->zilla->root . '' );
                     my $dir = path( "} . $self->archive . q{" );
                     if ( $dir->is_absolute ) {
-                        $self->log_error( [ 'Bad archive directory: %s', "$dir" ] );
-                        $self->log_error( [ 'Absolute path not allowed.' ] );
+                        $self->log_error( [ 'bad archive directory: %s', "$dir" ] );
+                        $self->log_error( [ 'absolute path not allowed' ] );
                         $self->abort();
                     };
                     if ( not $dir->is_dir ) {
-                        $self->log( [ 'Creating archive directory %s...', "$dir" ] );
+                        $self->log( [ 'creating archive directory %s', "$dir" ] );
                         $dir->mkpath();
                     };
                 } ],
@@ -535,7 +533,7 @@ sub configure {
                     for my $stage ( qw{ configure develop runtime test } ) {
                         if ( exists( $prereqs->{ $stage }->{ requires }->{ $module } ) ) {
                             if ( not $header ) {
-                                $self->log_error( 'Unwanted modules found:' );
+                                $self->log_error( 'unwanted modules found:' );
                                 $header = 1;
                             };
                             $self->log_error( [ '    %s in %s prereqs ', $module, $stage ] );
@@ -548,12 +546,18 @@ sub configure {
 
         [ 'CheckChangesHasContent' ],
 
+        #   Make sure there is no such tag yet, neither global nor local.
         [ 'Hook::BeforeRelease' => 'hg check tag' => {
             'hook' => [ q{
-                #   Make sure there is no such tag yet.
                 use Path::Tiny;
-                if ( path( '.hgtags' )->slurp_utf8 =~ m{ \Q$MY::version\E$}m ) {
-                    $self->abort( [ 'tag %s already exists', $MY::version ] );
+                my $version = $dist->version;
+                my $tags = path( '.hgtags' );
+                if ( $tags->slurp_utf8 =~ m{ \Q$version\E$}m ) {
+                    $self->abort( [ 'tag %s already exists', $version ] );
+                };
+                my $ltags = path( '.hg/localtags' );
+                if ( $ltags->exists and $ltags->slurp_utf8 =~ m{ \Q$version\E$}m ) {
+                    $self->abort( [ 'local tag %s already exists', $version ] );
                 };
             } ],
         } ],
@@ -572,6 +576,14 @@ sub configure {
             } ],
         } ],
 
+        $self->local_release ? (
+            [ 'Hook::BeforeRelease' => 'release note' => {
+                'hook' => [ q{
+                    $self->log( '*** Preparing to *local* release ***' );
+                } ],
+            } ],
+        ) : (
+        ),
         [ 'ConfirmRelease' ],       # Ask confirmation before uploading the release.
 
         [ 'Hook::Releaser' => 'tgz' => {
@@ -588,15 +600,15 @@ sub configure {
                     use Path::Tiny;
                     my $tgz = path( $arg );
                     my $dir = path( "} . $self->archive . q{" );
-                    $self->log( [ 'Copying %s to %s...', "$tgz", "$dir" ] );
+                    $self->log( [ 'copying %s to %s', "$tgz", "$dir" ] );
                     $tgz->copy( $dir->child( $tgz->basename ) );
                 } ],
             } ],
         ) : (
         ),
 
-        $self->fake_release ? (
-            [ 'FakeRelease' ],
+        $self->local_release ? (
+            # No need in `FakeRelease`: we have at least one releaser, it is enough.
         ) : (
             [ 'UploadToCPAN' ],
         ),
@@ -615,7 +627,7 @@ sub configure {
                 if ( $dirty ) {
                     $self->abort( 'hg status is not clean' );
                 };
-                path( '.hgtags' )->append( "$id $MY::version\n" );
+                path( '} . ( $self->local_release ? '.hg/localtags' : '.hgtags' ) . q{' )->append( sprintf( "%s %s\n", $id, $dist->version ) );
             } ],
         } ],
 
@@ -631,7 +643,7 @@ sub configure {
                 my $version = Perl::Version->new( $dist->version );
                 $version->inc_alpha;
                 path( 'VERSION' )->spew( $version );
-                $self->log( [ 'Next release will be %s', "$version" ] );
+                $self->log( [ 'next release will be %s', "$version" ] );
             } ],
         } ],
 
@@ -645,23 +657,23 @@ sub configure {
             } ],
         } ],
 
-        [ 'Hook::AfterRelease' => 'hg push' => {
-            'hook' => [
-                $self->fake_release ? ( q{
-                    $self->log( 'Fake release, skipping "hg push"...' );
-                } ) : ( q{
+        $self->local_release ? (
+        ) : (
+            [ 'Hook::AfterRelease' => 'hg push' => {
+                'hook' => [ q{
                     use IPC::System::Simple 'capture';
                     my @stdout = capture( 'hg', 'push' );
                     chomp( @stdout );
                     $self->log( "    $_" ) for @stdout;
-                } ),
-            ],
-        } ],
+                } ],
+            } ],
+        ),
 
         [ 'Hook::AfterRelease' => 'install' => {
             'hook' => [ q{
                 use autodie ':all';
                 use File::chdir;
+                $self->log( [ 'installing %s-%s', $dist->name, $dist->version ] );
                 local $CWD = $zilla->built_in;
                 system( 'cpanm', '--notest', '.' );
                     # ^ We run the tests on unpacked tarball before release, no need in running
@@ -725,7 +737,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version 0.006, released on 2015-08-14 00:31 UTC.
+Version 0.007, released on 2015-08-15 10:54 UTC.
 
 =head1 WHAT?
 
@@ -746,13 +758,12 @@ least for now.
 
 C<Str>, optional, default value 5.006.
 
-=head2 fake_release
+=head2 local_release
 
-If true (C<1>), release will be a fake one, i. e. no external operations will be done:
-C<UploadToCPAN> plugin will be replaced with C<FakeRelease> (which does nothing), and C<hg push>
-will not be performed.
+If true, release will be a local one, i. e. no external operations will be done: C<UploadToCPAN>
+and C<hg push> will be skipped, <hg tag> will create a local tag.
 
-Option can be set trough F<dist.ini> file or with C<FAKE_RELEASE> environment variable.
+Option can be set trough F<dist.ini> file or with C<DZIL_LOCAL_RELEASE> environment variable.
 
 C<Bool>, optional, default value is 0.
 
